Package: isingLenzMC
Version: 0.3.1
Date: 2026-02-26
Title: Monte Carlo for Classical Ising Model
Authors@R: c(
    person("Mehmet", "Suzen",
    email = "mehmet.suzen@physics.org", role = c("aut", "cre")))
Maintainer: Mehmet Suzen <mehmet.suzen@physics.org>
Depends: R (>= 3.0)
NeedsCompilation: yes
BuildVignettes: yes
Description: Classical Ising Model is a land mark system in statistical physics.The model explains the physics of spin glasses and magnetic materials, and cooperative phenomenon in general, for example phase transitions and neural networks.This package provides utilities to simulate one dimensional Ising Model with Metropolis and Glauber Monte Carlo with single flip dynamics in periodic boundary conditions. Utility functions for exact solutions are provided. Such as transfer matrix for 1D. Utility functions for exact solutions are provided. Example use cases are as follows: Measuring effective ergodicity and power-laws in so called functional-diffusion. Example usage contains parallel runs, fitting power-laws, finite size scaling, computing autocorrelation, uncertainty analysis and plotting utilities. 
License: GPL (>= 3)
Packaged: 2026-02-26 11:51:21 UTC; msuzen
Author: Mehmet Suzen [aut, cre]
Repository: CRAN
Date/Publication: 2026-02-26 12:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 19:46:32 UTC; unix
Archs: isingLenzMC.so.dSYM
