
# Effective ergodicity on the Ising model

This is an example application of the package. 
Measuring ergodicity rate for the one dimensional
ising Model. 

## Reproducing the dataset and plots. 

`run.R`             : Generate the data. 
`isingErgodicity.R` : Helper functions.  
`plotData.R`        : Plot using the data (double check the directory identifications for data and plots). 

## License. 

This project and all contributions are licensed under :
* All non-code  [![License: CC BY 4.0](https://i.creativecommons.org/l/by/4.0/88x31.png)](https://creativecommons.org/licenses/by/4.0/)
* Code under [![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

